pycocoa.geometry.Point2

Package pycocoa :: Module geometry :: Class Point2 |
[frames] | no frames]

# Class Point2

      object --+
               |
    bases._Type0 --+
                   |
               Point --+
                       |
                      Point2

Python Type, like Point, different signature.

Instance Methods
__init__(self, x=0, y=0) New Point2 keyword arguments. |
Inherited from `Point`: `__str__` Inherited from `bases._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Point`: `point`, `x`, `y` Inherited from `bases._Type0`: `NS`, `NSDelegate` Inherited from `object`: `__class__`

Method Details

### __init__(self, x=0, y=0) (Constructor) |
New Point2 keyword arguments. Overrides: object.__init__